/*
 * jSite2 - InsertListener.java - Copyright © 2008 David Roden
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */
package net.pterodactylus.jsite.core;

import java.util.EventListener;

/**
 * Interface for objects that want to be notified on events emitted by the
 * {@link InsertManager}.
 * 
 * @author David ‘Bombe’ Roden &lt;bombe@freenetproject.org&gt;
 */
public interface InsertListener extends EventListener {

	/**
	 * Notifies a listener that an insert was added.
	 * 
	 * @param insert
	 *            The insert that was added
	 */
	public void insertAdded(Insert insert);

	/**
	 * Notifies a listener that an insert was removed.
	 * 
	 * @param insert
	 *            The insert that was removed
	 */
	public void insertRemoved(Insert insert);

	/**
	 * Notifies a listener that an insert was started.
	 * 
	 * @param insert
	 *            The insert that was started
	 */
	public void insertStarted(Insert insert);

	/**
	 * Notifies a listener that an insert made some progress.
	 * 
	 * @param insert
	 *            The insert that made some progress
	 */
	public void insertProgressed(Insert insert);

	/**
	 * Notifies listeners that an insert generated a URI.
	 * 
	 * @param insert
	 *            The insert that generated a URI
	 * @param uri
	 *            The generated URI
	 */
	public void insertGeneratedURI(Insert insert, String uri);

	/**
	 * Notifies a listener that an insert has finished.
	 * 
	 * @param insert
	 *            The insert that has finished
	 */
	public void insertFinished(Insert insert);

}
